/***********************************************************************
* Copyright (c) 2011 Samu Juvonen <samu.juvonen@gmail.com>
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
************************************************************************/

#include <QApplication>
#include <QDebug>
#include <QDesktopServices>
#include <QFileInfo>
#include <QNetworkAccessManager>
#include <QSettings>

#include "Coquillo.h"

#include <core/MetaDataModel2.h>
#include <core/ModelDataInspector.h>
#include <gui/MainWindow.h>

Coquillo::Coquillo(QObject * parent)
: QObject(parent) {

	_networkManager = new QNetworkAccessManager(this);

	migrateSettings();
	writeDefaults();

	MetaDataModel2 * m = new MetaDataModel2(this);
	m->setNetworkManager(_networkManager);

	_window = new MainWindow(m);

	ModelDataInspector * inspector = new ModelDataInspector(this);
	inspector->setModel(m);

	QString location = QSettings().value("DefaultLocation").toString();

	if (QApplication::arguments().count() > 1) {
		const QFileInfo info(QApplication::arguments().last());

		if (info.exists() && info.isDir()) {
			location = info.absoluteFilePath();
		} else {
			qWarning() << "Error: Path" << info.absoluteFilePath() << "does not exist!";
		}
	}

	m->setDirectory(location);

	_window->show();
}

Coquillo::~Coquillo() {
	delete _window;
}

void Coquillo::migrateSettings() {
	QSettings settings;

	const int version = settings.value("Settings/Version").toInt();

	// Reset settings for Coquillo versions < 1.10
	// We don't bother trying to migrate older versions due to exhaustive
	// amount of breakage
	if (version < 10) {
		foreach (const QString key, settings.allKeys())
			settings.remove(key);
	}

	// Version 10 since Coquillo 1.10
	settings.setValue("Settings/Version", 10);
}

void Coquillo::writeDefaults() {

	QHash<QString, QVariant> defaults;

	// Location to use when starting up the application
	defaults.insert(
		"DefaultLocation",
		QDesktopServices::storageLocation(QDesktopServices::MusicLocation)
	);

	defaults.insert("CapitalizeNever", QString("%1%2")
		.arg("a, an, the, and, but, or, nor, at, by, for, from, in, into, of, ")
		.arg("off, on, onto, out, over, to, up, with, as"));

	defaults.insert("Widgets/MainWindowSize", QSize(940, 600));

	// Whether or not make Roman numerals always capitalized
	defaults.insert("CapitalizeRomanNumerals", true);

	// Substring length to use with substr patterns (%A, %B, %T, %G) in processor
	defaults.insert("SubstringPatternLength", 1);

	QSettings settings;
	
	foreach (QString key, defaults.keys()) {
		if (!settings.contains(key))
			settings.setValue(key, defaults.value(key));
	}
	
	settings.sync();
}
