/***********************************************************************
* Copyright (c) 2011 Samu Juvonen <samu.juvonen@gmail.com>
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
************************************************************************/

#ifndef METADATA_H
#define METADATA_H

#include <QHash>
#include <QVariant>

#include "MetaDataImage.h"

class MetaData {
	public:

		/**
		 * Field codes
		 *
		 * TitleField has to be first and PicturesField last, because it is being
		 * relied on around the code! The indexing also needs to be defragmented!
		 **/
		enum Field {
			TitleField, ArtistField, AlbumField, LengthField, YearField, DiscNumberField,
			NumberField, MaxNumberField, GenreField, CommentField, OriginalArtistField,
			ComposerField, UrlField, EncoderField, PathField, PicturesField
		};

		MetaData() : _pictureCount(0) { }

		QVariant get(Field field) const { return _data.value(field); }
		void set(Field field, const QVariant & value);

		bool null() const;
		bool has(Field field) const { return _data.contains(field); }
		bool valid() const { return has(MetaData::PathField); }

		QList<MetaData::Field> fields() const { return _data.keys(); }

		int imageCount() const { return _images.count(); }

		MetaDataImage image(int index) const { return _images.value(index); }
		QList<MetaDataImage> images() const { return _images; }
		
		void addImage(const MetaDataImage & image);
		void setImages(const QList<MetaDataImage> & images) { _images.clear(); _images = images; }

		void removeImage(int index);

	private:
		QHash<Field, QVariant> _data;
		QList<MetaDataImage> _images;
		
		int _pictureCount;
};

Q_DECLARE_METATYPE(MetaData)

#endif