/***********************************************************************
* Copyright (c) 2011 Samu Juvonen <samu.juvonen@gmail.com>
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
************************************************************************/

#include <QDebug>
#include <QSettings>

#include "MetaDataImage.h"

QHash<qint16, QImage> MetaDataImage::s_cache;
QHash<qint16, QImage> MetaDataImage::s_small;

MetaDataImage::MetaDataImage() : _type(0), _id(0) {
	
}

MetaDataImage::MetaDataImage(const QImage & image)
	: _type(0), _id(0) {

	setImage(image);
}

MetaDataImage::MetaDataImage(const QImage & image, int type, const QString & description)
	: _description(description), _type(type), _id(0) {

	setImage(image);
}

void MetaDataImage::setImage(const QImage & image) {
	if (image.isNull())
		return;
	
	_id = qChecksum((const char *)(image.bits()), image.byteCount());

	if (_id == 0)
		return;

	if (s_cache.contains(_id))
		return;

	QSettings s;

	if (s.value("ScaleCovers").toBool()) {
		const QSize size = QSize(
			s.value("ScaleWidth").toInt(),
			s.value("ScaleHeight").toInt()
		);
		
		s_cache[_id] = image.scaled(size, Qt::KeepAspectRatio);
	} else {
		s_cache[_id] = image;
		s_small[_id] = image.scaled(QSize(96, 96), Qt::KeepAspectRatio);
	}
}

QImage MetaDataImage::image() const {
	if (_id == 0)
		return QImage();
	
	return s_cache.contains(_id) ? s_cache[_id] : QImage();
}

QImage MetaDataImage::small() const {
	if (s_small.contains(_id))
		return s_small[_id];

	if (s_cache.contains(_id))
		return s_cache[_id];

	return QImage();
}

bool MetaDataImage::null() const {
	return image().isNull();
}
