/***********************************************************************
* Copyright (c) 2011 Samu Juvonen <samu.juvonen@gmail.com>
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
************************************************************************/

#ifndef METADATAIMAGE_H
#define METADATAIMAGE_H

#include <QHash>
#include <QImage>
#include <QString>

class MetaDataImage {

	public:
		enum Roles {
			ImageRole = Qt::DecorationRole,
			DescriptionRole = Qt::DisplayRole,
			MetaTypeRole = Qt::UserRole+32
		};

		enum Fields { ImageField, DescriptionField, TypeField };
		
		MetaDataImage();
		MetaDataImage(const QImage & image);
		MetaDataImage(const QImage & image, int type, const QString & description=QString());

		qint16 id() const { return _id; }

		void setImage(const QImage & image);
		QImage image() const;
		QImage small() const;

		bool null() const;

		void setDescription(const QString & descr) { _description = descr; }
		QString description() const { return _description; }

		void setType(int type) { _type = type; }
		int type() const { return _type; }

	private:
		QString _description;

		int _type;
		qint16 _id;

		static QHash<qint16, QImage> s_cache;
		static QHash<qint16, QImage> s_small;
};

#endif