/***********************************************************************
* Copyright (c) 2011 Samu Juvonen <samu.juvonen@gmail.com>
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
************************************************************************/

#ifndef METADATAWRITER_H
#define METADATAWRITER_H

#include <QObject>

#include "MetaData.h"

namespace TagLib {
	class Tag;

	namespace ID3v2 {
		class Tag;
	}
	
	namespace Ogg {
		class XiphComment;
	}
}

class MetaDataWriter : public QObject {
	Q_OBJECT

	public:
		MetaDataWriter(QObject * parent=0);

		void enqueue(const QString & path, const MetaData & data) { _items.insert(path, data); }
		void setQueue(const QMap<QString, MetaData> & items) { _items = items; }

	signals:
		void progress(int);
		void maximumChanged(int);
		void started();
		void finished();

	public slots:
		void write();

	private:
		enum FileType { UnknownFile, MpegFile, FlacFile, OggVorbisFile };

		int fileType(const QString & path) const;

		void writeGeneric(TagLib::Tag * tag, const MetaData & metaData) const;
		
		void writeTag(TagLib::ID3v2::Tag * tag, const MetaData & metaData) const;
		void writeTag(TagLib::Ogg::XiphComment * tag, const MetaData & metaData) const;

		QByteArray * imageToBytes(const QImage & image) const;

		QMap<QString, MetaData> _items;
	
};

#endif