/***********************************************************************
* Copyright (c) 2011 Samu Juvonen <samu.juvonen@gmail.com>
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
************************************************************************/

#ifndef DIRECTORYSELECTORWIDGET_H
#define DIRECTORYSELECTORWIDGET_H

#include <QWidget>

class QFileSystemModel;
class QLineEdit;
class QModelIndex;
class QTreeView;

class FileSystemProxyModel;

namespace Ui {
	class DirectorySelector;
};

class DirectorySelectorWidget : public QWidget {
	Q_OBJECT

	public:
		DirectorySelectorWidget(QWidget * parent=0);
		QString path() const;

		bool eventFilter(QObject * object, QEvent * event);

	signals:
		void bookmarked(const QString &);
		void pathChanged(const QString &);

	public slots:

		/**
		 * Changes visual root to current index's parent.
		 *
		 * @see setRootIndex(const QModelIndex &)
		 **/
		void goDirectoryUp();

		/**
		 * Sets the selected path and emits pathSelected(). (Or will it?)
		 *
		 * Will also set this path as visual root IF this directory is not a child
		 * for the current root.
		 **/
		void setPath(const QString &);

		/**
		 * Sets the visual root for the tree.
		 *
		 * Emits pathChanged() ONLY if current index is not a subdirectory of
		 * this directory.
		 **/
		void setRootIndex(const QModelIndex &);

		/**
		 * @see setRootIndex(const QModelIndex &)
		 **/
		void setRootPath(const QString &);

	private slots:
		void changePath(const QModelIndex &);
		void changeToTypedPath();

		void showTreeContextMenu(const QPoint &);

	private:
		Ui::DirectorySelector * _ui;
		QFileSystemModel * _model;
		FileSystemProxyModel * _proxy;
};

#endif
