/***********************************************************************
* Copyright (c) 2011 Samu Juvonen <samu.juvonen@gmail.com>
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
************************************************************************/

#ifndef EDITORWIDGET_H
#define EDITORWIDGET_H

#include <QPersistentModelIndex>

#include "DataWidget.h"

class QAbstractItemModel;
class QDataWidgetMapper;
class QNetworkAccessManager;
class QItemSelection;

namespace Ui {
	class EditorWidget;
}

class EditorWidget : public DataWidget {
	Q_OBJECT

	public:
		EditorWidget(QWidget * parent=0);
		~EditorWidget();

		void setModel(QAbstractItemModel * model);
		void setNetworkManager(QNetworkAccessManager * manager);

	public slots:
		void setSelection(const QItemSelection & selection);

	private slots:
		void automaticNumbering();
		void copyField(int field);
		void displayImageProperties(const QModelIndex & idx);
		void setImageDescription(const QString & text);
		void setImageType(const QString & typeString);

		void addImage();
		void exportCurrentImage();
		void removeCurrentImage();

		void submitChanges();

		void updateImagesTabText();
		void updateMetaDataChangeIndicators();

	private:
		Ui::EditorWidget * _ui;
		QDataWidgetMapper * _mapper;
		QDataWidgetMapper * _mapper2;
		QNetworkAccessManager * _networkManager;
		
		QHash<int, QString> _typeStrings;
		QString _importPath;
		QString _exportPath;
};

#endif
