/***********************************************************************
* Copyright (c) 2011 Samu Juvonen <samu.juvonen@gmail.com>
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
************************************************************************/

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>

class QLabel;
class QNetworkAccessManager;

class BookmarkModel;
class CddbSearchDialog;
class ProcessorWidget;

class MetaDataModel2;
typedef MetaDataModel2 MetaDataModel;

namespace Ui {
	class MainWindow;
}

class MainWindow : public QMainWindow {
	Q_OBJECT

	public:
		MainWindow(MetaDataModel * model, QWidget * parent=0);
		~MainWindow();

		QMenu * createPopupMenu();

		QList<QToolBar*> toolBars() const;
		QList<QDockWidget*> dockWidgets() const;
		
		bool eventFilter(QObject * object, QEvent * event);
		
	public slots:
		void setInterfaceLocked(bool state);
		void setToolBarIconSize(int size);
		void setToolBarButtonStyle(int style);

		void showError(const QString & error);

	protected:
		void closeEvent(QCloseEvent *);
		void showEvent(QShowEvent *);

	private slots:
		
		/**
		 * Fixes the reported selection of QItemSelectionModel's selectionChanged()
		 *
		 * By default QItemSelectionModel's signal ignores the first selected index
		 * when using Shift+Click or Ctrl+Click. Have to proxy the selection change
		 * to capture all currently selected indexes.
		 **/
		void proxyTableSelection();

		/**
		 * Invert selection in the track list.
		 **/
		void selectInverse();
		
		void selectNextIndex();
		void selectPreviousIndex();

		void setupBookmarkMenu();

		void showAboutDialog();
		void showBookmarkDialog();
		void showSettingsDialog();
		
		void showHeaderContextMenu(const QPoint & pos);

		/**
		 * Displays a progress bar for an ongoing operation in the MetaDataModel.
		 **/
		void afterModelAction();
		void beforeModelAction();

	private:
		void loadSettings();
		void setMetaDataModel(MetaDataModel * model);
		void setupToolBar();
		
		Ui::MainWindow * _ui;

		QLabel * _statusMessage;
		QNetworkAccessManager * _networkManager;

		BookmarkModel * _bookmarks;
		MetaDataModel * _model;
		CddbSearchDialog * _cddbSearch;
		ProcessorWidget * _processor;

};

#endif
